@@ -9,8 +9,9 @@ from pyprind.prog_class import Prog
 
 
 class ProgBar(Prog):
-    """Initializes a progress bar object that allows visuzalization
-        of an iterational computation in the standard output screen. 
+    """
+    Initializes a progress bar object that allows visuzalization
+    of an iterational computation in the standard output screen. 
 
     Keyword Arguments:
         iterations (int): number of iterations of the computation
@@ -60,8 +61,16 @@ class ProgBar(Prog):
                 self._print_eta()
         self.last_progress = progress
 
-    def update(self):
-        """Updates the progress bar in every iteration of the task."""
-        self.cnt += 1
+    def update(self, iterations=1):
+        """
+        Updates the progress bar in every iteration of the task.
+
+        Keyword arguments:
+            iterations (int): default argument can be changed to integer values
+                >=1 in order to update the progress indicators more than once 
+                per iteration.
+
+        """
+        self.cnt += iterations
         self._print_bar()
         self._finish() 
